@@ -5,7 +5,7 @@ use v5.20;
 use experimental 'signatures';
 use strict;
 
-our $VERSION=0.02;
+our $VERSION=0.03;
 
 sub new {
     my $s = shift;
@@ -189,7 +189,7 @@ sub zrangebyscore($s,$key,$min,$max) {
 
 =head1 NAME
 
-Postgredis -- PostgreSQL and Redis mashup!
+Postgredis -- PostgreSQL and Redis mashup
 
 =head1 SYNOPSIS
 
